@@ -1,4 +1,4 @@
-from typing import Any, Dict, Generic, Iterable, Optional, Sequence
+from typing import Any, ClassVar, Dict, Generic, Iterable, Optional, Sequence
 
 from dbdaora.keys import FallbackKey
 
@@ -6,19 +6,21 @@ from .. import DataSource
 
 
 class FallbackDataSource(DataSource, Generic[FallbackKey]):
+    key_separator: ClassVar[str] = ':'
+
     def make_key(self, *key_parts: Any) -> FallbackKey:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def get(self, key: FallbackKey) -> Optional[Dict[str, Any]]:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def get_many(
         self, keys: Iterable[FallbackKey]
     ) -> Sequence[Optional[Dict[str, Any]]]:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def put(self, key: FallbackKey, data: Dict[str, Any]) -> None:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def delete(self, key: FallbackKey) -> None:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
