@@ -16,6 +16,7 @@ from dbdaora.exceptions import (
     EntityNotFoundError,
     InvalidKeyAttributeError,
     InvalidQueryError,
+    RequiredClassAttributeError,
 )
 from dbdaora.keys import FallbackKey
 
@@ -30,7 +31,52 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
     entity_name: ClassVar[str]
     entity_cls: ClassVar[Type[Entity]]
     key_attrs: ClassVar[Sequence[str]]
-    many_attr_names: ClassVar[Union[Sequence[str], str]]
+    many_key_attrs: ClassVar[Union[Sequence[str], str]]
+    __skip_cls_validation__: Sequence[str] = ()
+
+    def __init_subclass__(
+        cls,
+        entity_name: Optional[str] = None,
+        entity_cls: Optional[Type[Entity]] = None,
+        key_attrs: Optional[Sequence[str]] = None,
+        many_key_attrs: Optional[Type[Entity]] = None,
+    ):
+        super().__init_subclass__()
+        entity_name = getattr(cls, 'entity_name', entity_name)
+        entity_cls = getattr(cls, 'entity_cls', entity_cls)
+        key_attrs = getattr(cls, 'key_attrs', key_attrs)
+        many_key_attrs = getattr(cls, 'many_key_attrs', many_key_attrs)
+
+        if cls.__name__ not in cls.__skip_cls_validation__:
+            missing_attrs = []
+
+            for name, value in (
+                ('entity_name', entity_name),
+                ('entity_cls', entity_cls),
+                ('key_attrs', key_attrs),
+            ):
+                if value is None:
+                    if name == 'entity_cls':
+                        has_entity_type = any(
+                            [
+                                cls.get_entity_type != base.get_entity_type  # type: ignore
+                                for base in cls.__bases__
+                            ]
+                        )
+                        name = 'entity_cls or get_entity_type'
+                    else:
+                        has_entity_type = False
+
+                    if not has_entity_type:
+                        missing_attrs.append(name)
+
+            if missing_attrs:
+                raise RequiredClassAttributeError(cls.__name__, missing_attrs)
+
+        cls.entity_name = entity_name  # type: ignore
+        cls.entity_cls = entity_cls  # type: ignore
+        cls.key_attrs = key_attrs  # type: ignore
+        cls.many_key_attrs = many_key_attrs or key_attrs  # type: ignore
 
     async def get_memory_data(
         self,
@@ -39,12 +85,12 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
         *,
         many: bool = False,
     ) -> Optional[EntityData]:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def get_memory_many(
         self, query: 'QueryMany[Entity, EntityData, FallbackKey]',
     ) -> List[Entity]:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def get_fallback_data(
         self,
@@ -53,29 +99,29 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
         for_memory: bool = False,
         many: bool = False,
     ) -> Optional[EntityData]:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def get_fallback_many(
         self, query: 'QueryMany[Entity, EntityData, FallbackKey]',
     ) -> List[Entity]:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     def make_entity(
         self,
         data: EntityData,
         query: 'BaseQuery[Entity, EntityData, FallbackKey]',
     ) -> Entity:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     def make_entity_from_fallback(
         self,
         data: EntityData,
         query: 'BaseQuery[Entity, EntityData, FallbackKey]',
     ) -> Entity:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def add_memory_data(self, key: str, data: EntityData) -> None:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def add_memory_data_from_fallback(
         self,
@@ -83,13 +129,13 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
         query: Union['BaseQuery[Entity, EntityData, FallbackKey]', Entity],
         data: EntityData,
     ) -> EntityData:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
-    def make_memory_data(self, entity: Entity) -> EntityData:
-        raise NotImplementedError()
+    def make_memory_data_from_entity(self, entity: Entity) -> EntityData:
+        raise NotImplementedError()  # pragma: no cover
 
     async def add_fallback(self, entity: Entity, *entities: Entity) -> None:
-        raise NotImplementedError()
+        raise NotImplementedError()  # pragma: no cover
 
     async def entity(
         self, query: 'Query[Entity, EntityData, FallbackKey]',
@@ -112,9 +158,8 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
     ) -> Entity:
         memory_key = self.memory_key(query)
         memory_data = await self.get_memory_data(memory_key, query)
-        from_fallback = False
 
-        if memory_data is None and not await self.already_got_not_found(query):
+        if not memory_data and not await self.already_got_not_found(query):
             fallback_data = await self.get_fallback_data(
                 query, for_memory=True
             )
@@ -125,16 +170,11 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
                 memory_data = await self.add_memory_data_from_fallback(
                     memory_key, query, fallback_data
                 )
-                from_fallback = True
 
-        if memory_data is None:
+        if not memory_data:
             raise EntityNotFoundError(query)
 
-        return (
-            self.make_entity_from_fallback(memory_data, query)
-            if from_fallback
-            else self.make_entity(memory_data, query)
-        )
+        return self.make_entity(memory_data, query)
 
     async def get_fallback(
         self,
@@ -160,7 +200,7 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
 
     async def add_memory(self, entity: Entity, *entities: Entity) -> None:
         memory_key = self.memory_key(entity)
-        memory_data = self.make_memory_data(entity)
+        memory_data = self.make_memory_data_from_entity(entity)
         await self.add_memory_data(memory_key, memory_data)
         await self.set_expire_time(memory_key)
         await self.add_fallback(entity)
